# BONSAI classifications Python package

This package is part of the [BONSAI database](http://bonsamurais.gitlab.io/bonsai/documentation/) created by the Getting The Data Right project.
The goal of this package is to provide the classification tables that are used in the project.

## Download Bonsai classifications as Excel Sheets

You can download the following Excel files:

- [activitytype_tree_bonsai.xlsx](_static/excel_files/activitytype_tree_bonsai.xlsx)
- [flowobject_tree_bonsai.xlsx](_static/excel_files/flowobject_tree_bonsai.xlsx)

## Contents

```{toctree}
:maxdepth: 2

Overview <readme>
Contributions & Help <contributing>
License <license>
Authors <authors>
Changelog <changelog>
Module Reference <api/modules>
```

## Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
